/**
 * @(#)RepmanWin.java
 *
 * Copyright: Copyright (c) 2003 Carnegie Mellon University
 *
 * This program is replication manager of Jboss servers which calls remote factories
 * to run or killing their local server. Communiction is done by RMI.
 */

import java.io.IOException;
import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

public class RepmanWin {

    /**
     * Remote reference to the Factory.
     */
    private RIFactory rmiFactory;

    public RepmanWin(String serverName)
           throws NotBoundException, MalformedURLException, RemoteException {

    	String service = "rmi://" + serverName;
   		this.rmiFactory = (RIFactory) Naming.lookup(service);

    }

    /**
     * The body of client. It continuously gets user input and executes associated RMI methods
     * in the logic node.
     */
    public void execute(String command)
                throws RemoteException, IOException {
    	
    		this.rmiFactory.launch(command);
    	
    }

    /**
     * Creates a client and starts it. Two parameters are expected, the first one as logic
     * name and the second one as client name.
     *
     * @param args array of input parameters
     */
    public static void main(String args[]) {
        // Check the number of parameters.
        if (args.length != 2) {
            System.out.println("Incorrect number of parameters");
            System.out.println("Usage: java RepmanWin <'run' or 'kill'> <'primary' or 'secondary'>");
            System.exit(1);
        }
        
        if (!(args[0].equals("run") || args[0].equals("kill"))) {
        	System.out.println("Incorrect command");
        	System.out.println("Usage: java RepmanWin <'run' or 'kill'> <'primary' or 'secondary'>");
        	System.exit(1);
        }
     
        if (!(args[1].equals("primary") || args[1].equals("secondary"))) {
        	System.out.println("Incorrect server name");
        	System.out.println("Usage: java RepmanWin <'run' or 'kill'> <'primary' or 'secondary'>");
        	System.exit(1);
        }
        
        try {
            // Create a RepmanWin and execute it.
        	if (args[1].equals("primary")){
        		String address = "128.2.222.50:1199/" + args[1];
        		RepmanWin objRepman = new RepmanWin(address);
        		objRepman.execute(args[0]);
        	}
        	else if (args[1].equals("secondary")){
        		String address = "128.2.222.27:1199/" + args[1];
        		RepmanWin objRepman = new RepmanWin(address);
        		objRepman.execute(args[0]);
        	}

        }
        catch (java.rmi.ConnectException e) {
            // Show error message and quit.
            System.err.println("Java RMI error: check if rmiregistry is running.");
            System.exit(1);
	}
        catch (java.rmi.NotBoundException e) {
            // Show error message and quit.
            System.err.println("Java RMI error: check if Factory is running.");
            System.exit(1);
        }

        catch (Exception e) {
            // Dump the exception information for debugging.
            System.out.println("Unexpected exception");
            e.printStackTrace();
            System.exit(1);
        }
    }
}
